"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var index_1 = require("../index");
var React = require("react");
var enzyme_1 = require("enzyme");
var data = [
    {
        id: 'a',
        name: 'X',
        age: 234
    },
    {
        id: 'b',
        name: 'Y',
        age: 235
    }
];
var fieldConfig = {
    id: {
        hidden: true
    },
    name: {
        header: 'Name'
    },
    age: {
        order: -1
    }
};
var TestTable = (function (_super) {
    __extends(TestTable, _super);
    function TestTable() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return TestTable;
}(index_1.default));
describe('Table', function () {
    var tTable = enzyme_1.shallow(React.createElement(TestTable, { data: data, primaryKey: 'id', fieldConfig: fieldConfig }));
    it('Has 3 children of class row', function () {
        expect(tTable.children().length).toEqual(3);
    });
    it('Each table column has class col', function () {
        tTable.children().forEach(function (row) {
            expect(row.children().every('.col')).toBeTruthy();
        });
    });
    describe('Header', function () {
        var tHeader = tTable.find(index_1.Header);
        it('Has correct key', function () {
            expect(tHeader.key()).toEqual('header');
        });
        it('Has correct data', function () {
            expect(tHeader.props().data).toMatchObject(fieldConfig);
        });
        describe('Row', function () {
            var tHeaderRow = tHeader.shallow().find(index_1.Row);
            var tShallowRow = tHeaderRow.shallow();
            it('Has correct classes', function () {
                expect(tHeaderRow.hasClass('header')).toBeTruthy();
            });
            it('Has correct props', function () {
                var tHeaderProps = tHeaderRow.props();
                expect(tHeaderProps.data).toMatchObject({
                    id: 'id',
                    name: 'Name',
                    age: 'age'
                });
                expect(tHeaderProps.config).toMatchObject(fieldConfig);
            });
            describe('Columns', function () {
                it('Are ordered correctly', function () {
                    expect(tShallowRow.childAt(0).key()).toEqual('age');
                    expect(tShallowRow.childAt(1).key()).toEqual('name');
                });
                it('Have correct content', function () {
                    expect(tShallowRow.childAt(1).html()).toContain('Name');
                    expect(tShallowRow.childAt(0).html()).toContain('age');
                });
                it('Have class col', function () {
                    expect(tShallowRow.children().children().every('.col')).toBeTruthy();
                });
            });
        });
    });
    describe('Rows', function () {
        var tRows = tTable.children().filter(index_1.Row);
        it('Contains 2 rows of correct class and key', function () {
            expect(tRows.length).toEqual(2);
            var tIndex = 0;
            tRows.forEach(function (row) {
                expect(row.key()).toEqual(data[tIndex].id);
                tIndex++;
            });
        });
        it('Columns have correct values and keys', function () {
            var tIndex = 0;
            tRows.forEach(function (row) {
                var tRowChildren = row.shallow().children();
                expect(tRowChildren.length).toEqual(2);
                expect(tRowChildren.at(0).html()).toContain(data[tIndex].age);
                expect(tRowChildren.at(0).key()).toEqual('age');
                expect(tRowChildren.at(1).html()).toContain(data[tIndex].name);
                expect(tRowChildren.at(1).key()).toEqual('name');
                tIndex++;
            });
        });
    });
});
//# sourceMappingURL=index.js.map