"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var React = require("react");
var header_1 = require("./header");
exports.Header = header_1.default;
var row_1 = require("./row");
exports.Row = row_1.default;
exports.Column = row_1.Column;
var util_1 = require("../lib/util");
/**
 * Base Table class
 *
 * Since React doesn't allow type parameters to be set in jsx, i'd suggest the creation of a custom class which extends this base class and includes a type parameter
 * @export
 * @class Table
 * @extends {React.Component<ITableProps<T>, Partial<ITableState>>}
 * @template T
 */
var Table = (function (_super) {
    __extends(Table, _super);
    function Table(props) {
        var _this = _super.call(this) || this;
        _this.state = {};
        _this.setSort = _this.setSort.bind(_this);
        return _this;
    }
    Table.prototype.render = function () {
        var _this = this;
        var tGridSize = this.props.gridSize || 12;
        var tClasses = [
            'table',
            'container',
            this.props.className
        ];
        var tHeaderColumnClasses = [
            this.props.headerColumnClassName,
            this.props.addClassesToHeader !== false ? this.props.columnClassName : ''
        ];
        var tHeaderClasses = [
            this.props.headerClassName,
            this.props.addClassesToHeader !== false ? this.props.rowClassName : ''
        ];
        var tData = this.props.data;
        if (this.state.sortField) {
            tData = tData.sort(function (a, b) {
                var tAField = a[_this.state.sortField];
                var tBField = b[_this.state.sortField];
                var tSortedFieldConfig = _this.props.fieldConfig[_this.state.sortField];
                var tSortFactor = _this.state.sortDir === 'asc' ? 1 : -1;
                if (tSortedFieldConfig.sortFunction) {
                    return tSortedFieldConfig.sortFunction(tAField, tBField, tSortFactor);
                }
                var tSort;
                if (typeof (tAField) === 'string') {
                    tSort = tAField.localeCompare(tBField);
                }
                else if (typeof (tAField) === 'number') {
                    tSort = tAField - tBField;
                }
                else {
                    tSort = 1;
                }
                return tSortFactor * tSort;
            });
        }
        return (React.createElement("div", { className: tClasses.join(' ') },
            React.createElement(header_1.default, { sortField: this.state.sortField, sortDir: this.state.sortDir, sortable: this.props.sortable, key: 'header', data: this.props.fieldConfig, className: util_1.combineClasses(tHeaderClasses), columnClassName: util_1.combineClasses(tHeaderColumnClasses), filteredClassName: this.props.filteredColumnClassName, onColumClick: this.setSort }),
            tData.map(function (entry, index) {
                var tKey = _this.props.data[index][_this.props.primaryKey] || index;
                return React.createElement(row_1.default, { key: tKey, sortField: _this.state.sortField, rowKey: tKey, data: entry, config: _this.props.fieldConfig, className: _this.props.rowClassName, columnClasses: _this.props.columnClassName, filteredColumnClasses: _this.props.filteredColumnClassName, onColumnClick: function (rowKey, columnKey) {
                        if (_this.props.onRowSelected) {
                            _this.props.onRowSelected(rowKey);
                        }
                        if (_this.props.onCellClick) {
                            _this.props.onCellClick(rowKey, columnKey);
                        }
                    } });
            })));
    };
    Table.prototype.setSort = function (key) {
        if (this.props.fieldConfig[key].sortable === false) {
            return;
        }
        if (key !== this.state.sortField) {
            return this.setState({
                sortField: key,
                sortDir: this.state.sortDir === undefined ? 'asc' : this.state.sortDir
            });
        }
        this.setState({
            sortDir: this.state.sortDir === 'asc' ? 'desc' : 'asc'
        });
    };
    return Table;
}(React.Component));
exports.Table = Table;
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = Table;
//# sourceMappingURL=index.js.map