import Table, { Header, Row } from '../index';
import * as React from 'react';
import { shallow } from 'enzyme';
const data = [
    {
        id: 'a',
        name: 'X',
        age: 234
    },
    {
        id: 'b',
        name: 'Y',
        age: 235
    }
];
const fieldConfig = {
    id: {
        hidden: true
    },
    name: {
        header: 'Name'
    },
    age: {
        order: -1
    }
};
class TestTable extends Table {
}
describe('Table', () => {
    const tTable = shallow(React.createElement(TestTable, { data: data, primaryKey: 'id', fieldConfig: fieldConfig }));
    it('Has 3 children of class row', () => {
        expect(tTable.children().length).toEqual(3);
    });
    it('Each table column has class col', () => {
        tTable.children().forEach(row => {
            expect(row.children().every('.col')).toBeTruthy();
        });
    });
    describe('Header', () => {
        const tHeader = tTable.find(Header);
        it('Has correct key', () => {
            expect(tHeader.key()).toEqual('header');
        });
        it('Has correct data', () => {
            expect(tHeader.props().data).toMatchObject(fieldConfig);
        });
        describe('Row', () => {
            const tHeaderRow = tHeader.shallow().find(Row);
            const tShallowRow = tHeaderRow.shallow();
            it('Has correct classes', () => {
                expect(tHeaderRow.hasClass('header')).toBeTruthy();
            });
            it('Has correct props', () => {
                const tHeaderProps = tHeaderRow.props();
                expect(tHeaderProps.data).toMatchObject({
                    id: 'id',
                    name: 'Name',
                    age: 'age'
                });
                expect(tHeaderProps.config).toMatchObject(fieldConfig);
            });
            describe('Columns', () => {
                it('Are ordered correctly', () => {
                    expect(tShallowRow.childAt(0).key()).toEqual('age');
                    expect(tShallowRow.childAt(1).key()).toEqual('name');
                });
                it('Have correct content', () => {
                    expect(tShallowRow.childAt(1).html()).toContain('Name');
                    expect(tShallowRow.childAt(0).html()).toContain('age');
                });
                it('Have class col', () => {
                    expect(tShallowRow.children().children().every('.col')).toBeTruthy();
                });
            });
        });
    });
    describe('Rows', () => {
        const tRows = tTable.children().filter(Row);
        it('Contains 2 rows of correct class and key', () => {
            expect(tRows.length).toEqual(2);
            let tIndex = 0;
            tRows.forEach((row) => {
                expect(row.key()).toEqual(data[tIndex].id);
                tIndex++;
            });
        });
        it('Columns have correct values and keys', () => {
            let tIndex = 0;
            tRows.forEach(row => {
                const tRowChildren = row.shallow().children();
                expect(tRowChildren.length).toEqual(2);
                expect(tRowChildren.at(0).html()).toContain(data[tIndex].age);
                expect(tRowChildren.at(0).key()).toEqual('age');
                expect(tRowChildren.at(1).html()).toContain(data[tIndex].name);
                expect(tRowChildren.at(1).key()).toEqual('name');
                tIndex++;
            });
        });
    });
});
//# sourceMappingURL=index.js.map